@@ -282,7 +282,7 @@ cbBatch <- tk2checkbutton(Envir$Select)
             if (is.numeric(Envir$Data$Dates) == TRUE ) { years <- Envir$Data$Dates } else {
             d <- as.Date(Envir$Data$Dates, format="%Y-%m-%d")                                                                                      # formattage de la date
             years <- as.numeric(format(d, format = "%Y")) }                                                                                             # on recupere les annees
-
+        
             if ( anyNA(d) == FALSE ) {} else { return(tkmessageBox(message="Wrong date format: must be 'yyyy-mm-dd'"
                                                                    ,icon = "warning", type = "ok", title="!Warning!")) }
 
@@ -637,14 +637,14 @@ cbBatch <- tk2checkbutton(Envir$Select)
                  plotB="NO", selectBox, log.trans, plotZ="YES", datashow="NO",
                  help.timestep, auto.timestep, time.step, help.aggreg, auto.aggreg, aggreg,
                  mix, outliers.re, na.replace, start, end, months, norm="NO", npsu,
-                 autocorr = "NO", spectrum="NO", anomaly="NO", a.barplot="NO", zsmooth="NO", local.trend="NO", test="NO", OnOK4) }}
+                 autocorr = "NO", spectrum="NO", anomaly="NO", a.barplot="NO", test.pettitt="NO", zsmooth="NO", local.trend="NO", test="NO", OnOK4) }}
 
           else{ site <- Site
           FULLoption(param, depth, sal, site, rawdata="NO", select="NO", resume.reg="NO", test.normality="NO",
                  plotB="NO", selectBox, log.trans, plotZ="YES", datashow="NO",
                  help.timestep, auto.timestep, time.step, help.aggreg, auto.aggreg, aggreg,
                  mix, outliers.re, na.replace, start, end, months, norm="NO", npsu,
-                 autocorr = "NO", spectrum="NO", anomaly="NO", a.barplot="NO", zsmooth="NO", local.trend="NO", test="NO", OnOK4) } }
+                 autocorr = "NO", spectrum="NO", anomaly="NO", a.barplot="NO", test.pettitt="NO", zsmooth="NO", local.trend="NO", test="NO", OnOK4) } }
      OK.but <- tk2button(LabeledFrame7, text="  Plot  ",command=OnOK, width=9)
      tkgrid(OK.but, column=0, row=1, sticky="w")
 #______________________________________________________________________________________________bouton d'appel du tableau des donnees regularisees
@@ -722,14 +722,14 @@ cbBatch <- tk2checkbutton(Envir$Select)
                  plotB="NO", selectBox, log.trans, plotZ="NO", datashow="YES",
                  help.timestep, auto.timestep, time.step, help.aggreg, auto.aggreg, aggreg,
                  mix, outliers.re, na.replace, start, end, months, norm="NO", npsu,
-                 autocorr = "NO", spectrum="NO", anomaly="NO", a.barplot="NO", zsmooth="NO", local.trend="NO", test="NO" , OnOK4) }}
+                 autocorr = "NO", spectrum="NO", anomaly="NO", test.pettitt="NO", a.barplot="NO", zsmooth="NO", local.trend="NO", test="NO" , OnOK4) }}
 
           else{ site <- Site
           FULLoption(param, depth, sal, site, rawdata="NO", select="NO", resume.reg="NO", test.normality="NO",
                  plotB="NO", selectBox, log.trans, plotZ="NO", datashow="YES",
                  help.timestep, auto.timestep, time.step, help.aggreg, auto.aggreg, aggreg,
                  mix, outliers.re, na.replace, start, end, months, norm="NO", npsu,
-                 autocorr = "NO", spectrum="NO", anomaly="NO", a.barplot="NO", zsmooth="NO", local.trend="NO", test="NO" , OnOK4) } }
+                 autocorr = "NO", spectrum="NO", anomaly="NO", test.pettitt="NO", a.barplot="NO", zsmooth="NO", local.trend="NO", test="NO" , OnOK4) } }
      OK1.but <- tk2button(LabeledFrame7, text=" Table ",command=OnOK1, width=9)
      tkgrid(OK1.but, column=1, row=1, sticky="w")
 
@@ -808,14 +808,14 @@ cbBatch <- tk2checkbutton(Envir$Select)
                  plotB="NO", selectBox, log.trans, plotZ="NO", datashow="NO",
                  help.timestep, auto.timestep, time.step, help.aggreg, auto.aggreg, aggreg,
                  mix, outliers.re, na.replace, start, end, months, norm="NO", npsu,
-                 autocorr = "NO", spectrum="NO", anomaly="NO", a.barplot="NO", zsmooth="NO", local.trend="NO", test="NO", OnOK4) }}
+                 autocorr = "NO", spectrum="NO", test.pettitt="NO", anomaly="NO", a.barplot="NO", zsmooth="NO", local.trend="NO", test="NO", OnOK4) }}
 
           else{ site <- Site
           FULLoption(param, depth, sal, site, rawdata="NO", select="NO", resume.reg="YES", test.normality="NO",
                  plotB="NO", selectBox, log.trans, plotZ="NO", datashow="NO",
                  help.timestep, auto.timestep, time.step, help.aggreg, auto.aggreg, aggreg,
                  mix, outliers.re, na.replace, start, end, months, norm="NO", npsu,
-                 autocorr = "NO", spectrum="NO", anomaly="NO", a.barplot="NO", zsmooth="NO", local.trend="NO", test="NO", OnOK4) }  }
+                 autocorr = "NO", spectrum="NO", anomaly="NO", test.pettitt="NO", a.barplot="NO", zsmooth="NO", local.trend="NO", test="NO", OnOK4) }  }
      OK2.but <- tk2button(LabeledFrame7, text=" Summary ",command=OnOK2, width=9)
      tkgrid(OK2.but, column=2, row=1, sticky="w")
 #_____________________________________________________________________________________fin du bouton des stats descriptives
@@ -833,18 +833,19 @@ cbBatch <- tk2checkbutton(Envir$Select)
      diagFrame <- tkwidget(LabeledFrame4,"labelframe",padx=0,pady=0)
      tkconfigure(diagFrame, borderwidth=0)
      tkpack(diagFrame, side="left")
-
+     
      cbDetrend <- tk2checkbutton(diagFrame)                                                               # check button pour outliers
      cbDetrendValue <- tclVar("0")
      tkconfigure(cbDetrend,variable=cbDetrendValue)
      tkgrid(tklabel(diagFrame, text="Use remainder for tests ?"), cbDetrend, sticky="w")                  # bouton pour tests avec remainders
-
+     
      rb17 <- tk2radiobutton(diagFrame)                                                                              # radio bouton du choix du diagnostic
      rb18 <- tk2radiobutton(diagFrame)
      rb19 <- tk2radiobutton(diagFrame)
      rb20 <- tk2radiobutton(diagFrame)
      rb21 <- tk2radiobutton(diagFrame)
      rb22 <- tk2radiobutton(diagFrame)
+	 rb30 <- tk2radiobutton(diagFrame)
      rb5Value <- tclVar("2")
      tkconfigure(rb17,variable=rb5Value,value="1")                                                    # valeur donnee a chaque bouton
      tkconfigure(rb18,variable=rb5Value,value="2")
@@ -852,12 +853,14 @@ cbBatch <- tk2checkbutton(Envir$Select)
      tkconfigure(rb20,variable=rb5Value,value="4")
      tkconfigure(rb22,variable=rb5Value,value="6")
      tkconfigure(rb21,variable=rb5Value,value="5")
+	 tkconfigure(rb30,variable=rb5Value,value="7")                                                #pettitt test 
      tkgrid(tklabel(diagFrame,text="Spectrum analysis*    "),rb17, sticky="w")                    # texte afficher avec chaque bouton
      tkgrid(tklabel(diagFrame,text="Autocorrelation    "),rb18, sticky="w")
      tkgrid(tklabel(diagFrame,text="Shapiro normality test    "),rb19, sticky="w")
      tkgrid(tklabel(diagFrame,text="Anomaly (color.plot)    "),rb20, sticky="w")
      tkgrid(tklabel(diagFrame,text="Anomaly (barplot)    "),rb22, sticky="w")
      tkgrid(tklabel(diagFrame,text="Seasonal decomposition*  "),rb21, sticky="w")
+	 tkgrid(tklabel(diagFrame,text="Pettitt test (cassure)  "),rb30, sticky="w")
 
      imgProcess <- tclVar()
      tcl("image","create","photo",imgProcess,file=file.path(path.package("TTAinterfaceTrendAnalysis"),"aide","imgProcess.gif",fsep=.Platform$file.sep))
@@ -930,7 +933,7 @@ cbBatch <- tk2checkbutton(Envir$Select)
           cbDetrendValue <- as.character(tclvalue(cbDetrendValue))
           if (cbDetrendValue=="1"){ test.on.remaider <- "YES" }
           else { test.on.remaider <- "NO" }
-
+          
           rb5Val <- as.character(tclvalue(rb5Value))
 
           if (rb5Val=="1"){ spectrum <- "YES" }
@@ -945,6 +948,8 @@ cbBatch <- tk2checkbutton(Envir$Select)
           else { a.barplot <- "NO" }
           if (rb5Val=="5"){ zsmooth <- "YES" }
           else { zsmooth <- "NO" }
+		  if (rb5Val=="7"){ test.pettitt <- "YES" }
+          else { test.pettitt <- "NO" }
 
           cbBatchValue <- as.character(tclvalue(cbBatchValue))
            if (cbBatchValue=="1"){ Envir$batch <- "YES" }
@@ -956,14 +961,14 @@ cbBatch <- tk2checkbutton(Envir$Select)
                  plotB="NO", selectBox, log.trans, plotZ="NO", datashow="NO",
                  help.timestep, auto.timestep, time.step, help.aggreg, auto.aggreg, aggreg,
                  mix, outliers.re, na.replace, start, end, months, norm="NO", npsu, test.on.remaider,
-                 autocorr, spectrum, anomaly, a.barplot, zsmooth, local.trend="NO", test="NO", OnOK4) }}
+                 autocorr, spectrum, anomaly, a.barplot, zsmooth, test.pettitt, local.trend="NO", test="NO", OnOK4) }}
 
           else{ site <- Site
           FULLoption(param, depth, sal, site, rawdata="NO", select="NO", resume.reg="NO",test.normality,
                  plotB="NO", selectBox, log.trans, plotZ="NO", datashow="NO",
                  help.timestep, auto.timestep, time.step, help.aggreg, auto.aggreg, aggreg,
                  mix, outliers.re, na.replace, start, end, months, norm="NO", npsu, test.on.remaider,
-                 autocorr, spectrum, anomaly, a.barplot, zsmooth, local.trend="NO", test="NO", OnOK4)  } }
+                 autocorr, spectrum, anomaly, a.barplot, zsmooth, test.pettitt, local.trend="NO", test="NO", OnOK4)  } }
      OK3.but <- tk2button(LabeledFrame4, image=imgProcess, text="Run ", compound="right", command=OnOK3, width=6)
      tkpack(OK3.but, side="right")
 #_______________________________________________________________________________fin du bouton de diagnostic
@@ -1076,7 +1081,7 @@ cbBatch <- tk2checkbutton(Envir$Select)
           cb10Value <- as.character(tclvalue(cb10Value))
           if (cb10Value=="1"){ local.trend <- "YES" }
            else { local.trend <- "NO" }
-
+          
           cbDetrendValue <- as.character(tclvalue(cbDetrendValue))
           if (cbDetrendValue=="1"){ test.on.remaider <- "YES" }
           else { test.on.remaider <- "NO" }
@@ -1099,13 +1104,13 @@ cbBatch <- tk2checkbutton(Envir$Select)
                  plotB="NO", selectBox, log.trans, plotZ="NO", datashow="NO",
                  help.timestep, auto.timestep, time.step, help.aggreg, auto.aggreg, aggreg,
                  mix, outliers.re, na.replace, start, end, months, norm, npsu, test.on.remaider,
-                 autocorr = "NO", spectrum="NO",anomaly="NO", a.barplot="NO", zsmooth="NO", local.trend, test, OnOK4) } }
+                 autocorr = "NO", spectrum="NO",anomaly="NO", test.pettitt="NO", a.barplot="NO", zsmooth="NO", local.trend, test, OnOK4) } }
                     else{ site <- Site
                           FULLoption(param, depth, sal, site, rawdata="NO", select="NO", resume.reg="NO",test.normality="NO",
                  plotB="NO", selectBox, log.trans, plotZ="NO", datashow="NO",
                  help.timestep, auto.timestep, time.step, help.aggreg, auto.aggreg, aggreg,
                  mix, outliers.re, na.replace, start, end, months, norm, npsu, test.on.remaider,
-                 autocorr = "NO", spectrum="NO",anomaly="NO", a.barplot="NO", zsmooth="NO", local.trend, test)}  }
+                 autocorr = "NO", spectrum="NO",anomaly="NO", test.pettitt="NO", a.barplot="NO", zsmooth="NO", local.trend, test)}  }
 
      OK4.but <- tk2button(LabeledFrame5, image=imgProcess, text="Run ", compound="right", command=OnOK4, width=6)
      tkpack(OK4.but, side="right")
